@@ -2,6 +2,8 @@ from .target import Target, TargetStates, action_valid_decorator_factory
 from .dummy_target import DummyTarget
 from .openocd_target import *
 from .gdb_target import *
+from .jlink_target import *
 from .qemu_target import *
 from .panda_target import *
+from .pypanda_target import *
 from .unicorn_target import *
